aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--modules/FindKDE4Internal.cmake16
1 files changed, 5 insertions, 11 deletions
diff --git a/modules/FindKDE4Internal.cmake b/modules/FindKDE4Internal.cmake
index 9cd93c8f..1eddbb8f 100644
--- a/modules/FindKDE4Internal.cmake
+++ b/modules/FindKDE4Internal.cmake
@@ -41,8 +41,7 @@
# KDE4_KNOTIFYCONFIG_LIBRARY- the knotifyconfig library
# KDE4_KROSSCORE_LIBRARY - the krosscore library
# KDE4_KTEXTEDITOR_LIBRARY - the ktexteditor library
-# KDE4_KNEPOMUK_LIBRARY - the knepomuk library
-# KDE4_KMETADATA_LIBRARY - the kmetadata library
+# KDE4_NEPOMUK_LIBRARY - the nepomuk library
# KDE4_PLASMA_LIBRARY - the plasma library
#
# KDE4_PLASMA_OPENGL_FOUND - TRUE if the OpenGL support of Plasma has been found, NOTFOUND otherwise
@@ -72,8 +71,7 @@
# KDE4_KROSSCORE_LIBS - the kross core library and all depending libraries
# KDE4_KROSSUI_LIBS - the kross ui library which includes core and all depending libraries
# KDE4_KTEXTEDITOR_LIBS - the ktexteditor library and all depending libraries
# KDE4_KNEPOMUK_LIBS - the knepomuk library and all depending libraries
# KDE4_KMETADATA_LIBS - the kmetadata library and all depending libraries
# KDE4_PLASMA_LIBS - the plasma library and all depending librairies
#
# This module defines a bunch of variables used as locations for install directories.
@@ -489,13 +487,9 @@ else (_kdeBootStrapping)
endif (UNIX)
# these targets do not always exist, since they are built conditionally:
- if(TARGET ${KDE4_TARGET_PREFIX}knepomuk)
- _kde4_set_lib_variables(KNEPOMUK knepomuk ${KDE4_TARGET_PREFIX})
- endif(TARGET ${KDE4_TARGET_PREFIX}knepomuk)
-
- if(TARGET ${KDE4_TARGET_PREFIX}kmetadata)
- _kde4_set_lib_variables(KMETADATA kmetadata ${KDE4_TARGET_PREFIX})
- endif(TARGET ${KDE4_TARGET_PREFIX}kmetadata)
+ if(TARGET ${KDE4_TARGET_PREFIX}nepomuk)
+ _kde4_set_lib_variables(NEPOMUK nepomuk ${KDE4_TARGET_PREFIX})
+ endif(TARGET ${KDE4_TARGET_PREFIX}nepomuk)
# and this one for compatibility:
set(KDE4_THREADWEAVER_LIBRARIES ${KDE4_TARGET_PREFIX}threadweaver )
@@ -72,8 +71,7 @@
# KDE4_KROSSUI_LIBS - the kross ui library which includes core and all depending libraries
# KDE4_KTEXTEDITOR_LIBS - the ktexteditor library and all depending libraries
-# KDE4_KNEPOMUK_LIBS - the knepomuk library and all depending libraries
-# KDE4_KMETADATA_LIBS - the kmetadata library and all depending libraries
+# KDE4_NEPOMUK_LIBS - the nepomuk library and all depending libraries
# KDE4_PLASMA_LIBS - the plasma library and all depending librairies
#